%global __provides_exclude_from ^%{_libdir}/noise/.*\\.so$

%global srcname music
%global appname org.pantheon.noise

Name:           noise
Summary:        The official elementary music player
Version:        0.4.2
Release:        3%{?dist}
License:        LGPLv2+

URL:            https://github.com/elementary/%{srcname}
Source0:        %{url}/archive/%{version}/%{name}-%{version}.tar.gz

# Add backported, upstream patch to fix building with newer, more strict
# vala versions: https://github.com/elementary/music/pull/299
Patch0:         00-fix-vala-040-type-error.patch

BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  gettext
BuildRequires:  intltool
BuildRequires:  libappstream-glib
BuildRequires:  vala >= 0.26

BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.39
BuildRequires:  pkgconfig(granite)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0)
BuildRequires:  pkgconfig(gstreamer-tag-1.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.11.6
BuildRequires:  pkgconfig(libgda-5.0)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libpeas-1.0)
BuildRequires:  pkgconfig(libpeas-gtk-1.0)
BuildRequires:  pkgconfig(taglib_c)
BuildRequires:  pkgconfig(zeitgeist-2.0)

Requires:       hicolor-icon-theme

# noise explicitly requires the sqlite libgda database provider
Requires:       libgda-sqlite%{?_isa}


%description
Noise is a fast and beautiful GTK3 audio player with a focus on music
and libraries. It handles external devices, CDs, and album art. Noise
utilizes Granite for a consistent and slick UI.


%package        devel
Summary:        The official elementary music player (development headers)
Requires:       %{name}%{?_isa} = %{version}-%{release}
%description    devel
Noise is a fast and beautiful GTK3 audio player with a focus on music
and libraries. It handles external devices, CDs, and album art. Noise
utilizes Granite for a consistent and slick UI.

This package contains files needed for developing with noise.


%prep
%autosetup -n %{srcname}-%{version} -p1


%build
mkdir build && pushd build
%cmake ..
%make_build
popd


%install
pushd build
%make_install
popd

%find_lang noise


%check
desktop-file-validate \
    %{buildroot}/%{_datadir}/applications/%{appname}.desktop

appstream-util validate-relax --nonet \
    %{buildroot}/%{_datadir}/metainfo/%{appname}.appdata.xml


%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig


%files -f noise.lang
%doc AUTHORS README.md
%license COPYING

%{_bindir}/noise

%{_libdir}/libnoise-core.so.0
%{_libdir}/libnoise-core.so.0.1

%{_libdir}/noise/

%{_datadir}/applications/%{appname}.desktop
%{_datadir}/glib-2.0/schemas/%{appname}.gschema.xml
%{_datadir}/icons/hicolor/*/apps/multimedia-audio-player.svg
%{_datadir}/metainfo/%{appname}.appdata.xml
%{_datadir}/noise/


%files devel
%{_libdir}/libnoise-core.so
%{_libdir}/pkgconfig/noise-core.pc

%{_includedir}/noise-core/

%{_datadir}/vala/vapi/noise-core.deps
%{_datadir}/vala/vapi/noise-core.vapi


%changelog
* Tue May 01 2018 Fabio Valentini <decathorpe@gmail.com> - 0.4.2-3
- Add backported patch to fix building with newer versions of vala.

* Sat Jan 06 2018 Fabio Valentini <decathorpe@gmail.com> - 0.4.2-2
- Remove icon cache scriptlets, replaced by file triggers.

* Mon Nov 27 2017 Fabio Valentini <decathorpe@gmail.com> - 0.4.2-1
- Update to version 0.4.2.

* Sat Nov 04 2017 Fabio Valentini <decathorpe@gmail.com> - 0.4.1-3
- Rebuild for granite soname bump.

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.4.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Fri Jul 28 2017 Fabio Valentini <decathorpe@gmail.com> - 0.4.1-1
- Update to version 0.4.1.

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.4.0.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Apr 22 2017 Fabio Valentini <decathorpe@gmail.com> - 0.4.0.3-1
- Update to version 0.4.0.3.

* Thu Feb 09 2017 Fabio Valentini <decathorpe@gmail.com> - 0.4.0.2-7
- Filter provides to exclude internal plugins.

* Sat Jan 28 2017 Fabio Valentini <decathorpe@gmail.com> - 0.4.0.2-6
- Rename bundled icon to prevent file conflicts.

* Wed Jan 25 2017 Fabio Valentini <decathorpe@gmail.com>
- Remove explicit BR: /usr/bin/pkgconfig.

* Mon Jan 23 2017 Fabio Valentini <decathorpe@gmail.com> - 0.4.0.2-5
- Make BR on /usr/bin/pkg-config explicit.

* Tue Jan 03 2017 Fabio Valentini <decathorpe@gmail.com> - 0.4.0.2-4
- Move appdata to "approved location".

* Tue Jan 03 2017 Fabio Valentini <decathorpe@gmail.com> - 0.4.0.2-3
- Make libgda-sqlite dependency arched.

* Sat Dec 31 2016 Fabio Valentini <decathorpe@gmail.com> - 0.4.0.2-2
- Clean up spec file.

* Thu Dec 01 2016 Fabio Valentini <decathorpe@gmail.com> - 0.4.0.2-1
- Update to version 0.4.0.2.

* Thu Sep 29 2016 Fabio Valentini <decathorpe@gmail.com> - 0.4.0.1-3
- Mass rebuild.

* Wed Sep 28 2016 Fabio Valentini <decathorpe@gmail.com> - 0.4.0.1-2
- Spec file cleanups.

* Tue Sep 20 2016 Fabio Valentini <decathorpe@gmail.com> - 0.4.0.1-1
- Update to version 0.4.0.1.

* Mon Sep 19 2016 Fabio Valentini <decathorpe@gmail.com> - 0.4-2
- Spec file cosmetics.

* Thu Aug 11 2016 Fabio Valentini <decathorpe@gmail.com> - 0.4-1
- Update to version 0.4.


